@@ -40,7 +40,7 @@
 #' \item \code{model_info} named list contating basic information about model, like package, version of package and type.
 #' }
 #'
-#' @references Explanatory Model Analysis. Explore, Explain and Examine Predictive Models. \url{http://ema.drwhy.ai/}
+#' @references Explanatory Model Analysis. Explore, Explain and Examine Predictive Models. \url{https://ema.drwhy.ai/}
 #' @rdname explain
 #' @export
 #' @importFrom stats predict
@@ -64,6 +64,7 @@
 #' aps_lm <- explain(aps_lm_model4, data = apartments, label = "model_4v", y = apartments$m2.price,
 #'                                    predict_function = predict)
 #'
+#' \donttest{
 #' # user provided predict_function
 #' aps_ranger <- ranger::ranger(m2.price~., data = apartments, num.trees = 50)
 #' custom_predict <- function(X.model, newdata) {
@@ -88,9 +89,9 @@
 #' # keep in mind that for binary classification y parameter has to be numeric  with 0 and 1 values
 #' titanic_ranger_exp <- explain(titanic_ranger, data = titanic_imputed, y = titanic_imputed$survived)
 #'
-#' # multilabel classification
+#' # multiclass task
 #' hr_ranger <- ranger::ranger(status~., data = HR, num.trees = 50, probability = TRUE)
-#' # keep in mind that for multilabel classification y parameter has to be a factor,
+#' # keep in mind that for multiclass y parameter has to be a factor,
 #' # with same levels as in training data
 #' hr_ranger_exp <- explain(hr_ranger, data = HR, y = HR$status)
 #'
@@ -100,7 +101,6 @@
 #' aps_lm_explainer4 <- explain(aps_lm_model4, data = apartments, label = "model_4v",
 #'                              model_info = model_info)
 #'
-#' \donttest{
 #' # simple function
 #' aps_fun <- function(x) 58*x$surface
 #' aps_fun_explainer <- explain(aps_fun, data = apartments, y = apartments$m2.price, label="sfun")
@@ -264,8 +264,14 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
   }
 
   if (is.null(model_info)) {
-    # extract defaults
-    task_subtype <- check_if_multilabel(model, predict_function, data[1:2,])
+    # let's try to extract defaults
+    # need to rows otherwise the predict function may convert matrix to vector
+    if (!is.null(data) && nrow(data) > 1) {
+      task_subtype <- check_if_multiclass(model, predict_function, data[1:2, , drop = FALSE])
+    } else {
+      # no way to guess
+      task_subtype <- FALSE
+    }
     model_info <- model_info(model, is_multiclass = task_subtype)
     verbose_cat("  -> model_info        :  package", model_info$package[1], ", ver.", model_info$ver[1], ", task", model_info$type, "(", color_codes$yellow_start,"default",color_codes$yellow_end, ")", "\n", verbose = verbose)
   } else {
@@ -292,7 +298,7 @@ explain.default <- function(model, data = NULL, y = NULL, predict_function = NUL
     verbose_cat("  -> model_info        :  Otherwise I will not be able to calculate residuals or loss function.\n", verbose = verbose)
   } else if (!is.factor(y) & model_info$type == "multiclass") {
     verbose_cat("  -> model_info        :  Model info detected multiclass task but 'y' is a", class(y)[1], ".  (",color_codes$red_start,"WARNING",color_codes$red_end,")\n", verbose = verbose)
-    verbose_cat("  -> model_info        :  By deafult classification tasks supports only factor 'y' parameter. \n", verbose = verbose)
+    verbose_cat("  -> model_info        :  By deafult multiclass tasks supports only factor 'y' parameter. \n", verbose = verbose)
     verbose_cat("  -> model_info        :  Consider changing to a factor vector with true class names.\n", verbose = verbose)
     verbose_cat("  -> model_info        :  Otherwise I will not be able to calculate residuals or loss function.\n", verbose = verbose)
   }
@@ -385,8 +391,8 @@ is_y_in_data <- function(data, y) {
   }))
 }
 
-# check if model whether model is multilabel classification task
-check_if_multilabel <- function(model, predict_function, sample_data) {
+# check whether model is multiclass task
+check_if_multiclass <- function(model, predict_function, sample_data) {
   response_sample <- try(predict_function(model, sample_data), silent = TRUE)
   !is.null(dim(response_sample))
 }
@@ -396,7 +402,7 @@ residual_function_default <- function(model, data, y, predict_function = yhat) {
   y - predict_function(model, data)
 }
 
-# default residual function for multiclass problems
+# default residual function for multiclass tasks
 residual_function_multiclass <- function(model, data, y, predict_function = yhat) {
   y_char <- as.character(y)
   pred <- predict_function(model, data)
